module.exports = function(config) {
  config.entry = {
    "my_app": "./assets/my_app.js",
  };
};
